Title: [170426] trunk/Tools
Revision
170426
Author
m.pak...@samsung.com
Date
2014-06-25 05:25:20 -0700 (Wed, 25 Jun 2014)

Log Message

[EFL] Remove WebKit1 related code from scripts
https://bugs.webkit.org/show_bug.cgi?id=134195

Reviewed by Laszlo Gombos.

After removing WebKit1 from EFL port, still there is some code left related to DumpRenderTree,
EWebLauncher. Also running layout tests does not require adding -2/--webkit-test-runner switch.

* Scripts/run-launcher: MiniBrowser now runs as default without -2 switch.
* Scripts/webkitdirs.pm:
(builtDylibPathForName): Remove reference to libewebkit.so
* Scripts/webkitpy/layout_tests/run_webkit_tests.py:
(_set_up_derived_options): Script runs WKTR by default.
* Scripts/webkitpy/performance_tests/perftestsrunner.py:
(PerfTestsRunner.__init__): Ditto.
* Scripts/webkitpy/port/efl.py:
(EflPort._search_paths): Remove efl-wk2 from baseline search path.
(EflPort.show_results_html_file): Run MiniBrowser as result viewer.

Modified Paths

Diff

Modified: trunk/Tools/ChangeLog (170425 => 170426)


--- trunk/Tools/ChangeLog	2014-06-25 12:04:42 UTC (rev 170425)
+++ trunk/Tools/ChangeLog	2014-06-25 12:25:20 UTC (rev 170426)
@@ -1,3 +1,24 @@
+2014-06-25  Michał Pakuła vel Rutka  <m.pak...@samsung.com>
+
+        [EFL] Remove WebKit1 related code from scripts
+        https://bugs.webkit.org/show_bug.cgi?id=134195
+
+        Reviewed by Laszlo Gombos.
+
+        After removing WebKit1 from EFL port, still there is some code left related to DumpRenderTree, 
+        EWebLauncher. Also running layout tests does not require adding -2/--webkit-test-runner switch.
+
+        * Scripts/run-launcher: MiniBrowser now runs as default without -2 switch.
+        * Scripts/webkitdirs.pm:
+        (builtDylibPathForName): Remove reference to libewebkit.so
+        * Scripts/webkitpy/layout_tests/run_webkit_tests.py:
+        (_set_up_derived_options): Script runs WKTR by default.
+        * Scripts/webkitpy/performance_tests/perftestsrunner.py:
+        (PerfTestsRunner.__init__): Ditto.
+        * Scripts/webkitpy/port/efl.py:
+        (EflPort._search_paths): Remove efl-wk2 from baseline search path.
+        (EflPort.show_results_html_file): Run MiniBrowser as result viewer.
+
 2014-06-25  Laszlo Gombos  <l.gom...@samsung.com>
 
         Remove build guard for progress element

Modified: trunk/Tools/Scripts/run-launcher (170425 => 170426)


--- trunk/Tools/Scripts/run-launcher	2014-06-25 12:04:42 UTC (rev 170425)
+++ trunk/Tools/Scripts/run-launcher	2014-06-25 12:25:20 UTC (rev 170426)
@@ -45,14 +45,8 @@
 checkFrameworks();
 
 # Set paths according to the build system used
-if (isGtk()) {
+if (isGtk() || isEfl()) {
     $launcherPath = catdir($productDir, "bin", "MiniBrowser");
-} elsif (isEfl()) {
-    if (isWK2()) {
-        $launcherPath = catdir($productDir, "bin", "MiniBrowser");
-    } else {
-        $launcherPath = catdir($productDir, "bin", "EWebLauncher");
-    }
 }
 
 $launcherPath && -x $launcherPath or die "Can't find the launcher command";

Modified: trunk/Tools/Scripts/webkitdirs.pm (170425 => 170426)


--- trunk/Tools/Scripts/webkitdirs.pm	2014-06-25 12:04:42 UTC (rev 170425)
+++ trunk/Tools/Scripts/webkitdirs.pm	2014-06-25 12:25:20 UTC (rev 170426)
@@ -829,10 +829,7 @@
         return "NotFound";
     }
     if (isEfl()) {
-        if (isWK2()) {
-            return "$configurationProductDir/lib/libewebkit2.so";
-        }
-        return "$configurationProductDir/lib/libewebkit.so";
+        return "$configurationProductDir/lib/libewebkit2.so";
     }
     if (isWinCE()) {
         return "$configurationProductDir/$libraryName";

Modified: trunk/Tools/Scripts/webkitpy/layout_tests/run_webkit_tests.py (170425 => 170426)


--- trunk/Tools/Scripts/webkitpy/port/efl.py	2014-06-25 12:04:42 UTC (rev 170425)
+++ trunk/Tools/Scripts/webkitpy/port/efl.py	2014-06-25 12:25:20 UTC (rev 170426)
@@ -110,11 +110,7 @@
 
     def _search_paths(self):
         search_paths = []
-        if self.get_option('webkit_test_runner'):
-            search_paths.append(self.port_name + '-wk2')
-            search_paths.append('wk2')
-        else:
-            search_paths.append(self.port_name + '-wk1')
+        search_paths.append('wk2')
         search_paths.append(self.port_name)
         return search_paths
 
@@ -129,8 +125,6 @@
         # FIXME: We should find a way to share this implmentation with Gtk,
         # or teach run-launcher how to call run-safari and move this down to WebKitPort.
         run_launcher_args = ["file://%s" % results_filename]
-        if self.get_option('webkit_test_runner'):
-            run_launcher_args.append('-2')
         # FIXME: old-run-webkit-tests also added ["-graphicssystem", "raster", "-style", "windows"]
         # FIXME: old-run-webkit-tests converted results_filename path for cygwin.
         self._run_script("run-launcher", run_launcher_args)
_______________________________________________
webkit-changes mailing list
webkit-changes@lists.webkit.org
https://lists.webkit.org/mailman/listinfo/webkit-changes

Reply via email to
--- trunk/Tools/Scripts/webkitpy/layout_tests/run_webkit_tests.py	2014-06-25 12:04:42 UTC (rev 170425)
+++ trunk/Tools/Scripts/webkitpy/layout_tests/run_webkit_tests.py	2014-06-25 12:25:20 UTC (rev 170426)
@@ -382,8 +382,8 @@
     if options.run_singly:
         options.verbose = True
 
-    # The GTK+ port only support WebKit2 so it always uses WKTR.
-    if options.platform == "gtk":
+    # The GTK+ and EFL ports only support WebKit2 so they always use WKTR.
+    if options.platform == "gtk" or options.platform == "efl":
         options.webkit_test_runner = True
 
 

Modified: trunk/Tools/Scripts/webkitpy/performance_tests/perftestsrunner.py (170425 => 170426)


--- trunk/Tools/Scripts/webkitpy/performance_tests/perftestsrunner.py	2014-06-25 12:04:42 UTC (rev 170425)
+++ trunk/Tools/Scripts/webkitpy/performance_tests/perftestsrunner.py	2014-06-25 12:25:20 UTC (rev 170426)
@@ -66,8 +66,8 @@
             self._host = Host()
             self._port = self._host.port_factory.get(self._options.platform, self._options)
 
-        # The GTK+ port only supports WebKit2, so it always uses WKTR.
-        if self._port.name().startswith("gtk"):
+        # The GTK+ and EFL ports only supports WebKit2, so they always use WKTR.
+        if self._port.name().startswith("gtk") or self._port.name().startswith("efl"):
             self._options.webkit_test_runner = True
 
         self._host.initialize_scm()

Modified: trunk/Tools/Scripts/webkitpy/port/efl.py (170425 => 170426)

